pub struct CapabilityFlags(/* private fields */);Expand description
Hardware capability flags. Stable across backends; new bits append.
Implementations
Sourceimpl CapabilityFlags
impl CapabilityFlags
pub const FP64: Self
pub const FP32: Self
pub const TF32: Self
pub const FP16: Self
pub const BF16: Self
pub const FP8_E4M3: Self
pub const FP8_E5M2: Self
pub const FP4: Self
pub const INT8: Self
pub const INT4: Self
pub const TENSOR_CORES: Self
pub const WMMA: Self
pub const SPARSE_2_4: Self
pub const TRANSFORMER_ENGINE: Self
pub const UNIFIED_MEMORY: Self
pub const HOST_PINNED: Self
pub const PEER_ACCESS: Self
pub const ASYNC_ALLOC: Self
pub const HBM: Self
pub const NVLINK: Self
pub const INFINITY_FABRIC: Self
pub const COOPERATIVE_LAUNCH: Self
pub const DYNAMIC_PARALLELISM: Self
pub const GRAPHS: Self
pub const MULTI_STREAM: Self
pub const FLASH_ATTN: Self
pub const RAYTRACING: Self
pub const NCCL: Self
pub const RCCL: Self
pub const MPI_AWARE: Self
pub const HVX: Self
pub const HMX: Self
pub const ANE: Self
Sourceimpl CapabilityFlags
impl CapabilityFlags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CapabilityFlags
impl CapabilityFlags
Sourcepub const fn iter(&self) -> Iter<CapabilityFlags>
pub const fn iter(&self) -> Iter<CapabilityFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CapabilityFlags>
pub const fn iter_names(&self) -> IterNames<CapabilityFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.