#[non_exhaustive]pub enum Error {
BackendUnavailable(&'static str),
Unsupported(&'static str),
OutOfMemory,
LaunchFailure {
code: i32,
},
InvalidArgument(&'static str),
Backend {
backend: BackendKind,
code: i64,
},
Other(&'static str),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Backend not compiled in or runtime library not found.
Unsupported(&'static str)
Operation is not supported by the selected device / driver.
OutOfMemory
Out of device or pinned host memory.
LaunchFailure
Kernel launch failed; opaque driver code stored verbatim.
InvalidArgument(&'static str)
Misuse: violated an _unchecked precondition.
Backend
Backend-specific error wrapped as a code so we don’t allocate on hot paths. Backends keep their own decode tables.
Other(&'static str)
Anything else.